# TestPlanSearchQueryModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str, none_type** |  | [optional] 
**description** | **str, none_type** |  | [optional] 
**build** | **str, none_type** |  | [optional] 
**product_name** | **str, none_type** |  | [optional] 
**status** | [**[TestPlanStatusModel], none_type**](TestPlanStatusModel.md) |  | [optional] 
**global_ids** | **[int], none_type** |  | [optional] 
**is_locked** | **bool, none_type** |  | [optional] 
**locked_date** | [**DateRangeModel**](DateRangeModel.md) |  | [optional] 
**automatic_duration_timer** | **[bool], none_type** |  | [optional] 
**created_by_ids** | **[str], none_type** |  | [optional] 
**created_date** | [**DateRangeModel**](DateRangeModel.md) |  | [optional] 
**start_date** | [**DateRangeModel**](DateRangeModel.md) |  | [optional] 
**end_date** | [**DateRangeModel**](DateRangeModel.md) |  | [optional] 
**tag_names** | **[str], none_type** |  | [optional] 
**attributes** | **{str: ([str],)}, none_type** |  | [optional] 
**is_deleted** | **bool, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


